==> 2.3.zip: piwigo/language/ro_RO/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
$lang['All sub-albums of private albums become private'] = 'Toate sub-albumele ale albumelor private devin private';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Ca precatuie urmatoarele pluginuri au fost dezactivate. Trebuie sa le verifici de actualizari inainte de a le activa';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Ca precautie urmatoarele teme au fost dezactivate. Trebuie sa verifici de actualizari inainte de a le activa.';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, inainte de <b>?></b>, insert:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Numai un administrator poate face upgrade. Te rog logheaza-te mai jos.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Numai prefixurile thumbnailurilor si adresa de mail a webmasterului au fost salvate';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Ruleaza o verificare de mentenanta in [Administration>Tools>Maintenance] daca intampini probleme';
$lang['SQL queries'] = 'Interogari SQL';
$lang['Statistics'] = 'Statistici';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Aceasta pagina upgradeaza baza de date de la o versiunea mai veche de Piwigo la cea noua.
In acest moment rulezi <strong>release %s</strong>';
$lang['total SQL time'] = 'timpul total SQL';
$lang['total upgrade time'] = 'Timpul total pentru upgrade';
$lang['Upgrade from version %s to %s'] = 'Upgradeaza de la versiunea  %s la %s';
$lang['Upgrade informations'] = 'Informatiile pentru upgrade';
$lang['Upgrade'] = 'Upgradeaza';
$lang['User permissions and group permissions have been erased'] = 'Userii si permisiunile grupurilor au fost sterse';
$lang['You do not have access rights to run upgrade'] = 'Nu ai acces pentru a face upgrade';
?>

==> 14.5.0.zip: piwigo/language/ro_RO/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+
$lang['All sub-albums of private albums become private'] = 'Toate sub-albumele ale albumelor private devin private';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'Ca precatuie urmatoarele pluginuri au fost dezactivate. Trebuie sa le verifici de actualizari inainte de a le activa';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'Ca precautie urmatoarele teme au fost dezactivate. Trebuie sa verifici de actualizari inainte de a le activa.';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'In <i>%s</i>, inainte de <b>?></b>, insert:';
$lang['Only administrator can run upgrade: please sign in below.'] = 'Numai un administrator poate face upgrade. Te rog logheaza-te mai jos.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'Numai prefixurile thumbnailurilor si adresa de mail a webmasterului au fost salvate';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'Ruleaza o verificare de mentenanta in [Administration>Tools>Maintenance] daca intampini probleme';
$lang['SQL queries'] = 'Interogari SQL';
$lang['Statistics'] = 'Statistici';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'Aceasta pagina upgradeaza baza de date de la o versiunea mai veche de Piwigo la cea noua.
In acest moment rulezi <strong>release %s</strong>';
$lang['total SQL time'] = 'timpul total SQL';
$lang['total upgrade time'] = 'Timpul total pentru upgrade';
$lang['Upgrade from version %s to %s'] = 'Upgradeaza de la versiunea  %s la %s';
$lang['Upgrade informations'] = 'Informatiile pentru upgrade';
$lang['Upgrade'] = 'Upgradeaza';
$lang['User permissions and group permissions have been erased'] = 'Userii si permisiunile grupurilor au fost sterse';
$lang['You do not have access rights to run upgrade'] = 'Nu ai acces pentru a face upgrade';
$lang['Discover what\'s new in Piwigo %s'] = 'Descopera ce este nou in Piwigo %s';
